@@ -21,9 +21,11 @@ double (*nrfunc)(double *, dMat &, dMat &);
 #define SQR(a) (sqrarg=(a),sqrarg*sqrarg)
 static double sqrarg;
 
+/*
 #ifdef _WIN32
 #define finite _finite
-#endif
+#endiff
+*/
 
 //#define MAX(X,Y) ((X) > (Y) ? : (X) : (Y))
 
@@ -374,7 +376,8 @@ void powell(double *p, double **xi, int n, double ftol, int *iterate,
 /*
          if (_finite(*fret) == FALSE) {
 */         
-         if (finite(*fret) == FALSE) {
+/*         if (finite(*fret) == FALSE) {  */
+           if (R_FINITE(*fret) == FALSE) {
             errorflag = 1;
             throw ("NAN in routine brent");
          }
